@@ -13,6 +13,10 @@ use with real numpy or pandas data.
 from tqdm import tqdm
 from time import time
 
+from lightgbm import LGBMClassifier
+import xgboost as xgb
+
+import sklearn.dummy
 import sklearn.datasets
 import sklearn.linear_model
 import sklearn.tree
@@ -71,13 +75,20 @@ class ClassificationAnalyzer():
 
     def __init__(self,
                  random_state = 42,
-                 max_depth = 7,
+                 max_depth = 5,
+                 n_estimators = 100,
+                 use_subsample = 0.8,
+                 n_jobs = -1,
                  simulate_data = False):
 
-
         self.random_state = random_state
+
+        self.n_estimators = n_estimators
+        self.use_subsample = use_subsample
+
         self.max_depth = max_depth
         self.is_fit = False
+        self.n_jobs = n_jobs
 
         self._initialize_models()
         self._initialize_metrics()
@@ -88,17 +99,52 @@ class ClassificationAnalyzer():
 
     def _initialize_models(self):
 
+        self.dummy = sklearn.dummy.DummyClassifier(strategy = "prior")
+
         # Set random state / seeds for these
-        self.logistic_reg = sklearn.linear_model.LogisticRegression()
-        self.ridge = sklearn.linear_model.RidgeClassifier()
+
+        self.logistic_reg = sklearn.linear_model.LogisticRegression(penalty = "none",
+                                                                    n_jobs = self.n_jobs)
+
+        self.logistic_l1 = sklearn.linear_model.LogisticRegression(penalty = "l1",
+                                                                   solver = "saga",
+                                                                   n_jobs=self.n_jobs)
+
+        self.logistic_l2 = sklearn.linear_model.LogisticRegression(penalty = "l2",
+                                                                   solver = "saga",
+                                                                   n_jobs=self.n_jobs)
+
+        self.logistic_elastic = sklearn.linear_model.LogisticRegression(penalty = "elasticnet",
+                                                                        solver = "saga",
+                                                                        n_jobs=self.n_jobs)
+
+        self.ridge = sklearn.linear_model.RidgeClassifier(normalize = True)
+
         self.svc = sklearn.svm.SVC()
+
         self.nb = sklearn.naive_bayes.GaussianNB()
+        self.nb_complement = sklearn.naive_bayes.ComplementNB()
+
         self.knn = sklearn.neighbors.KNeighborsClassifier()
+
         self.dec_tree = sklearn.tree.DecisionTreeClassifier(max_depth=self.max_depth)
         self.extr_tree = sklearn.ensemble.ExtraTreesClassifier(max_depth=self.max_depth)
         self.random_forest = sklearn.ensemble.RandomForestClassifier(max_depth=self.max_depth)
-        self.bagging_clf = sklearn.ensemble.BaggingClassifier(max_features=0.4,
-                                                              max_samples=0.4)
+        self.bagging_clf = sklearn.ensemble.BaggingClassifier(max_features=0.8,
+                                                              max_samples=self.use_subsample)
+
+        self.xgb_clf = xgb.XGBClassifier(
+            n_estimators = self.n_estimators,
+            max_depth = self.max_depth,
+            subsample = self.use_subsample,
+            tree_method="approx"
+                                         )
+
+        self.lgb_clf = LGBMClassifier(
+            n_estimators=self.n_estimators,
+            max_depth=self.max_depth,
+            num_leaves=64
+        )
 
         # TODO: Organize into model types so each model can .fit on data made for it.
         # Logistic, Linear classifiers. SVC. KNN.
@@ -115,12 +161,17 @@ class ClassificationAnalyzer():
 
         # A list of named tuples of all models to loop through.
         self.models = [
+            (self.dummy, "dummy_prior_clf"),
             (self.logistic_reg, "logistic_reg"),
+            (self.logistic_l1, "logistic_l1"),
+            (self.logistic_l2, "logistic_l2"),
             (self.ridge, "ridge"),
             (self.nb, "nb"),
             (self.dec_tree, "dec_tree"),
             (self.extr_tree, "extr_tree"),
-            (self.bagging_clf, "bagging_clf")
+            (self.bagging_clf, "bagging_clf"),
+            (self.xgb_clf, "xgb_clf"),
+            (self.lgb_clf, "lgb_clf")
         ]
 
     def show_models(self):
@@ -226,9 +277,18 @@ class ClassificationAnalyzer():
         self.X_valid = X_valid
         self.y_valid = y_valid
 
+
+    def _update_validation_ready_models(self):
+        """
+        Models with early stopping should include validation sets.
+
+        :return:
+        """
+        pass
+
     def split_val_train(self,
                         train_fraction = 4/5,
-                        method = "time_series",
+                        method = "stochastic",
                         verbose = True):
         """
         Splits data into train and validation splits.
@@ -236,6 +296,7 @@ class ClassificationAnalyzer():
 
         :param X:
         :param y:
+        :param: method ("stochastic", "time_series")
         :return:
         """
 
@@ -244,6 +305,13 @@ class ClassificationAnalyzer():
 
         length_of_X = len(X)
 
+        if method == "stochastic":
+            self.X_train, self.X_valid, self.y_train, self.y_valid = sklearn.model_selection.train_test_split(
+                X, y, train_size = train_fraction,
+                stratify = y,
+                random_state=self.random_state
+            )
+
         if method == "time_series":
             # TODO: Add stochastic and time-series variants.
 
@@ -255,17 +323,16 @@ class ClassificationAnalyzer():
             self.X_valid = X.iloc[split_at_id:, :]
             self.y_valid = y.iloc[split_at_id:]
 
-        elif method == "stochastic":
-            self.X_train, self.X_valid, self.y_train, self.y_valid = sklearn.model_selection.train_test_split(
-                X, y, train_size = train_fraction,
-                stratify = y,
-                random_state=self.random_state
-            )
 
-        else:
-            pass
+
 
         self.y_true = self.y_valid
+        self._update_validation_ready_models()
+
+
+
+
+
 
     def cross_validate(self):
         pass
